@@ -1,7 +1,7 @@
 name = "doreah"
 desc = "Small toolkit of utilities for python projects"
 
-version = 1,5,6
+version = 1,6,9
 versionstr = ".".join(str(n) for n in version)
 
 author = {
@@ -15,10 +15,13 @@ requires = [
 	"mechanicalsoup",
 	"requests",
 	"pyyaml",
-	"beautifulsoup4"
+	"beautifulsoup4",
+	"jinja2>2.11"
 ]
 resources = [
-	'res/login.pyhp'
+	'res/*',
+	'res/*/*',
+	'res/*/*/*'
 ]
 
 commands = {
